Installation
============

To install Awpy, you must have Python >= 3.11, and you can simply run

``pip install awpy``

To check your current Awpy version, run 

``pip show awpy``

To see what data Awpy makes available for download (e.g., `.tri` world geometry, parsed nav files, etc.), you can run

``awpy get --help``
